==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebRowSelectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectionEventArgsDetailDescriptionMetadata } from "./WebRowSelectionEventArgsDetailDescriptionMetadata";
import { WebRowSelectionEventArgsDescription } from "./WebRowSelectionEventArgsDescription";
/**
 * @hidden
 */
export let WebRowSelectionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowSelectionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowSelectionEventArgsDescriptionMetadata.a == null) {
                WebRowSelectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowSelectionEventArgsDescriptionMetadata.c(WebRowSelectionEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebRowSelectionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebRowSelectionEventArgsDescriptionMetadata.a);
            WebRowSelectionEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowSelectionEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebRowSelectionEventArgsDetail");
        }
        static d(a) {
            WebRowSelectionEventArgsDescriptionMetadata.b(a);
            a.ad("WebRowSelectionEventArgs", () => new WebRowSelectionEventArgsDescription());
            a.ac("WebRowSelectionEventArgs", WebRowSelectionEventArgsDescriptionMetadata.a);
        }
    }
    WebRowSelectionEventArgsDescriptionMetadata.$t = markType(WebRowSelectionEventArgsDescriptionMetadata, 'WebRowSelectionEventArgsDescriptionMetadata');
    WebRowSelectionEventArgsDescriptionMetadata.a = null;
    return WebRowSelectionEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebRowSelectionEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowSelectionEventArgsDetailDescriptionMetadata } from "./WebRowSelectionEventArgsDetailDescriptionMetadata";
import { WebRowSelectionEventArgsDescription } from "./WebRowSelectionEventArgsDescription";
/**
 * @hidden
 */
export let WebRowSelectionEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowSelectionEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowSelectionEventArgsDescriptionMetadata.a == null) {
                WebRowSelectionEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowSelectionEventArgsDescriptionMetadata.c(WebRowSelectionEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebRowSelectionEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebRowSelectionEventArgsDescriptionMetadata.a);
            WebRowSelectionEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RowSelectionEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebRowSelectionEventArgsDetail");
        }
        static d(a) {
            WebRowSelectionEventArgsDescriptionMetadata.b(a);
            a.ae("WebRowSelectionEventArgs", () => new WebRowSelectionEventArgsDescription());
            a.ad("WebRowSelectionEventArgs", WebRowSelectionEventArgsDescriptionMetadata.a);
        }
    }
    WebRowSelectionEventArgsDescriptionMetadata.$t = markType(WebRowSelectionEventArgsDescriptionMetadata, 'WebRowSelectionEventArgsDescriptionMetadata');
    WebRowSelectionEventArgsDescriptionMetadata.a = null;
    return WebRowSelectionEventArgsDescriptionMetadata;
})();
